import React, { useEffect } from 'react';
import { isFunction } from 'lodash';
import { isNonEmptyString, _window, _process, SSR } from 'primeobjects-helper-util';
export var getRecaptchaToken = function (id) {
    var elemId = isNonEmptyString(id) ? "recaptcha_".concat(id) : '';
    return isNonEmptyString(elemId) && _window.grecaptcha.enterprise.getResponse(_window[elemId]);
};
export var Recaptcha = function (props) {
    var style = props.style, className = props.className;
    var id = isNonEmptyString(props.id) ? "recaptcha_".concat(props.id) : "recaptcha_core";
    var scriptId = "".concat(id, "_script");
    var functionId = "".concat(id, "_onLoadRecaptcha").replace(/-/g, '').replace(/_/g, '');
    var solution = _process.solution;
    var recaptchaSiteKey = solution.keys.recaptchaSiteKey;
    var isSSR = SSR == true;
    useEffect(function () {
        if (!isSSR && isNonEmptyString(id) && !document.getElementById(scriptId)) {
            if (!isFunction(_window[functionId])) {
                _window[functionId] = function () {
                    _window[id] = _window.grecaptcha.enterprise.render(id, {
                        sitekey: recaptchaSiteKey,
                        theme: 'light'
                    });
                };
                _window[scriptId] = document.createElement("script");
                _window[scriptId].id = scriptId;
                _window[scriptId].src = "https://www.google.com/recaptcha/enterprise.js?onload=".concat(functionId, "&render=explicit");
                document.body.appendChild(_window[scriptId]);
            }
        }
        return function () {
            if (_window[functionId])
                _window[functionId] = null;
            if (_window[scriptId])
                _window[scriptId].remove();
        };
    }, [isSSR, functionId, id, scriptId, recaptchaSiteKey]);
    return React.createElement("div", { id: id, style: style, className: className });
};
export default Recaptcha;
